from django.dispatch import receiver
from django.db.models.signals import post_save, pre_delete

from .models import LiveBlogEntry
from .tasks import firebase_update_timestamp


@receiver([post_save, pre_delete], sender=LiveBlogEntry)
def update_entry(sender, instance, *args, **kwargs):
    """
    Notify Firebase with updated timestamp
    """
    firebase_update_timestamp.delay(instance.liveblog_id)



from django.db import models
from django.utils import timezone


class SpecialCoverageManager(models.Manager):
    def get_by_identifier(self, identifier):
        identifier_id = identifier.split(".")[-1]
        return super(SpecialCoverageManager, self).get_queryset().get(id=identifier_id)

    def active(self):
        qs = super(SpecialCoverageManager, self).get_queryset()
        now = timezone.now()

        return qs.filter(
            start_date__lte=now, end_date__gte=now
        ) | qs.filter(
            start_date__lte=now, end_date__isnull=True
        )

    def inactive(self):
        qs = super(SpecialCoverageManager, self).get_queryset()
        now = timezone.now()

        return qs.filter(start_date__lte=now, end_date__lte=now)



from celery import shared_task
import requests

from django.conf import settings
from django.utils import timezone


@shared_task(default_retry_delay=5)
def firebase_update_timestamp(liveblog_id):
    endpoint = getattr(settings, 'LIVEBLOG_FIREBASE_NOTIFY_ENDPOINT', None)
    if endpoint:
        url = endpoint.format(liveblog_id=liveblog_id)
        resp = requests.put(url, json={
            'updatedAt': timezone.now().isoformat(),
        })
        resp.raise_for_status()



from django.apps import AppConfig


class LiveBlogConfig(AppConfig):
    name = 'bulbs.liveblog'

    def ready(self):
        # Recommended way to import signals in Django 1.7+
        import bulbs.liveblog.signals  # NOQA



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('videos', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='videohubvideo',
            name='id',
            field=models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True),
        ),
    ]
